function [T,Y]=nde2d(t,xy0)
% NDE2D - a 2D nonlinear differential equations
%          dx/dt=x-y
%          dy/dt=x^2-4
% [T,Y]=nde2d(t,xy0)
% INPUT 
%      t - time vector/span for which the solution should be calculated
%    xy0 - initial conditions, two values xy0=[x0 y0];
% OUTPUT
%      Y - solution matrix. Each column correspond to each coordinate,
%          i.e., Y=[x, y].
%      T - time index

options = odeset('RelTol',1e-4,'AbsTol',[1e-4]);
[T,Y] = ode45(@nonlindif,t,xy0,options);


function dvec=nonlindif(t,vec)
% Here we simply write the system of first order differential 
% equations. Each equation in the system is treated as a 
% coordinate. In this case there are two equations, thus 
% two coordinates
% dx/dt=-x + x^3
% dy/dt=-2y

% coordinates
x=vec(1);
y=vec(2);

% Vector of coordinates second order dif. eq. 
dvec=zeros(2,1);

% dx/dt=...
dvec(1)=x-y;
% dy/dt=...
dvec(2)=x^2-4;




