function [T,Y]=nde3d_lorenz(t,xyz0)
% NDE2D - a 3D nonlinear differential equation (Lorenz)

% [T,Y]=nde3d_lorenz(t,xyz0)
% INPUT 
%      t - time vector/span for which the solution should be calculated
%    xyz0 - initial conditions, three values xy0=[x0 y0 z0];
% OUTPUT
%      Y - solution matrix. Each column correspond to each coordinate,
%          i.e., Y=[x, y, z].
%      T - time index

options = odeset('RelTol',1e-4,'AbsTol',[1e-4]);
[T,Y] = ode45(@nonlindif,t,xyz0,options);


function dvec=nonlindif(t,vec)
%The Lorenz equations

%constants
global sigma r b;

% coordinates
x=vec(1);
y=vec(2);
z=vec(3);

% Vector of coordinates third order dif. eq. 
dvec=zeros(3,1);

% dx/dt=...
dvec(1)=sigma*(y-x);
% dy/dt=...
dvec(2)=r*x - y - x*z;
% dz/dt=...
dvec(3)=x*y - b*z;




